

--[[

The complete parsing function. Since the order of text in the combat log is likely to differ in
different languages, this entire function is included  in the localization class.

The function is given an input line from the combat log, and parses that line to determine its meaning.
The final step in each section is to return the extracted values. These lines need not be updated, but
the correct info must be extracted into the relevant fields.

Note the use of numeric values for avoids, critical hits, dmg types, and morale/power. These numbers
correspond to the orderings in the four lists directly above this comment block.

You will need to know something about lua pattern matching and/or regex's to attempt to translate this
section. See http://www.lua.org/pil/20.2.html for more details.

]]--

L["Parse"] = function(line)

	-- 1) Damage line ---
	
	local initiatorName,avoidAndCrit,skillName,targetNameAmountAndType = string.match(line,"^(.*) gelang ein (.*)Treffer mit (.*) gegen (.*)%.$");
	
	if (initiatorName ~= nil) then
		
		initiatorName = string.gsub(initiatorName,"^Der ","");
		initiatorName = string.gsub(initiatorName,"^Dem ","");
		
		local avoidType =
			string.match(avoidAndCrit,"^teilweise geblockter") and 8 or
			string.match(avoidAndCrit,"^teilweise parierter") and 9 or
			string.match(avoidAndCrit,"^teilweise ausgewichener") and 10 or 1;
		local critType =
			string.match(avoidAndCrit,"kritischer $") and 2 or
			string.match(avoidAndCrit,"zerst\195\182rerischer $") and 3 or 1;
		
		skillName = string.gsub(skillName, "\"", "");
		
		local targetName,amount,dmgType,moralePower = string.match(targetNameAmountAndType,"^(.*) f\195\188r ([%d,]*) (.*) auf (.*)$");
		-- damage was absorbed
		if targetName == nil then
			targetName = string.gsub(targetNameAmountAndType,"^den ","");
			targetName = string.gsub(targetNameAmountAndType,"^die ","");
			
			amount = 0;
			dmgType = 10;
			moralePower = 3;
		-- some damage was dealt
		else
			targetName = string.gsub(targetName,"^den ","");
			targetName = string.gsub(targetName,"^die ","");
			
			amount = string.gsub(amount,",","")+0;
			-- note there may be no damage type
			dmgType = 
				dmgType == "Punkte Schaden des Typs \"Allgemein\""  and 1 or
				dmgType == "Punkte Schaden des Typs \"Feuer\"" and 2 or
				dmgType == "Punkte Schaden des Typs \"Blitz\"" and 3 or
				dmgType == "Punkte Schaden des Typs \"Frost\"" and 4 or
				dmgType == "Punkte Schaden des Typs \"S\195\164ure\"" and 5 or
				dmgType == "Punkte Schaden des Typs \"Schatten\"" and 6 or
				dmgType == "Punkte Schaden des Typs \"Licht\"" and 7 or
				dmgType == "Punkte Schaden des Typs \"Beleriand-Art\"" and 8 or
				dmgType == "Punkte Schaden des Typs \"Westernis-Art\"" and 9 or
				dmgType == "Punkte Schaden des Typs \"Uralte Zwergenart\"" and 10 or 11;
			moralePower = (moralePower == "Moral" and 1 or moralePower == "Kraft" and 2 or 3);
		end
		
		-- Currently ignores damage to power
		if (moralePower == 2) then return nil end
		
		-- Update
		return 1,initiatorName,targetName,skillName,amount,avoidType,critType,dmgType;
	end
	
	-- 2) Heal line --
	--     (note the distinction with which self heals are now handled)
	--     (note we consider the case of heals of zero magnitude, even though they presumably never occur)

	
	---HEAL auf andere
	---Der Ambur wandte "Heilung" mit "Herz der Gefhrten" auf die Amtholdiel an, was 1,049 Punkte Moral wiederherstellte.
	---Amtholdiel applied a heal with Inner Flame to the Blood-raven restoring 91 points to Morale.
	local initiatorName,crit,skillName,targetName,amount,type = string.match(line,"^(.*) wandte \"(.*)Heilung\" mit (.*) auf (.*) an, was ([%d,]*) Punkte (.*) wiederherstellte.");
	
	if (initiatorName ~= nil) then
		initiatorName = string.gsub(initiatorName,"^Der ","");
		initiatorName = string.gsub(initiatorName,"^Die ","");

		local critType =
			crit == "kritische " and 2 or
			crit == "zerst\195\182rerische " and 3 or 1;
		
		targetName = string.gsub(targetName,"^die ","");
		targetName = string.gsub(targetName,"^den ","");
		skillName = string.gsub(skillName, "\"", "");
		amount = string.gsub(amount,",","")+0;
		moralePower = (type == "Moral" and 1 or type == "Kraft" and 2 or 3);
		
		return (moralePower == 2 and 4 or 3),initiatorName,targetName,skillName,amount,critType;
	end

	-- Heal was absorbed (eg: incoming healing = 0%?)
	--[[
	if moralePower == 3 then
		targetName = string.gsub(targetName,"^den ","");
		targetName = string.gsub(targetName,"^die ","");
		targetName = string.gsub(targetName,"^der ","");
		targetName = string.gsub(targetName,"^dem ","");
		amount = 0;
		return (moralePower == 2 and 4 or 3),initiatorName,targetName,skillName,amount,critType;
	end
	]]--
	
	---HEAL auf sich selbst
	---Innere Flamme verursacht bei der Amtholdiel "Heilung" und stellt 97 Punkte Moral wieder her.
	---Sign of Power: Istari Heal applied a heal to Amtholdiel restoring 987 points to Morale.
	local skillName,targetName,crit,amount,type = string.match(line,"^(.*) verursacht bei (.*) \"(.*)Heilung\" und stellt ([%d,]*) Punkte (.*) wieder her.");
	if (skillName ~= nil) then
		skillName = string.gsub(skillName, "\"", "");
		targetName = string.gsub(targetName,"^der ","");
		targetName = string.gsub(targetName,"^dem ","");
		local initiatorName = targetName; 
		local critType =
			crit == "kritische " and 2 or
			crit == "zerst\195\182rerische " and 3 or 1;
		amount = string.gsub(amount,",","")+0;
		moralePower = (type == "Moral" and 1 or type == "Kraft" and 2 or 3);

		return (moralePower == 2 and 4 or 3),initiatorName,targetName,skillName,amount,critType;
	end

	-- 3) Buff line --
	---Die Amtholdiel wandte "Vorteil" mit "Verbesserung: Zeichen der Wildnis: Wut" auf Geist der Natur an.

	local initiatorName,skillName,targetName = string.match(line,"^(.*) wandte \"Vorteil\" mit (.*) auf (.*) an%.$");
	
	if (initiatorName ~= nil) then
		initiatorName = string.gsub(initiatorName,"^Die ","");
		initiatorName = string.gsub(initiatorName,"^Der ","");
		targetName = string.gsub(targetName,"^den ","");
		targetName = string.gsub(targetName,"^die ","");
		
		-- Update
		return 15,initiatorName,targetName,skillName;
	end
	
	-- 4) Avoid line --
	---bungspuppe wollte die Amtholdiel mit "DNT - Training Dummy Swing" treffen, aber !!!!!!!!!!SIE!!!!!!!! konterte den Versuch mit "Parieren".
	---Der Angmarim-Kundschafter wollte die Phillipa mit "ein schwacher Fernkampfangriff" treffen, aber sie konterte den Versuch mit "Ausweichen".
	---Absorbieren,Ausweichen, blocken und co...
	local initiatorName,targetName,skillName,erSie,avoidType = string.match(line,"^(.*) wollte (.*) mit (.*) treffen\, aber (.*)konterte den Versuch mit (.*).");
	
	if (initiatorName ~= nil) then
		initiatorName = string.gsub(initiatorName,"^Der ","");
		initiatorName = string.gsub(initiatorName,"^Die ","");
		targetName = string.gsub(targetName,"^den ","");
		targetName = string.gsub(targetName,"^die ","");
		skillName = string.gsub(skillName, "\"", "");
		avoidType = string.gsub(avoidType, "\"", "");
		avoidType = 
			string.match(avoidType,"Blocken") and 5 or
			string.match(avoidType,"Parieren") and 6 or
			string.match(avoidType,"Ausweichen") and 7 or
			string.match(avoidType,"Widerstehen") and 4 or
			string.match(avoidType,"Immunit\195\164t") and 3 or 1;
		
		-- Sanity check: must have avoided in some manner
		if (avoidType == 1) then return nil end
		return 1,initiatorName,targetName,skillName,0,avoidType,1,10;
	end
	
	---Verfehlen
	---The Training-dummy missed trying to use DNT - Training Dummy Swing on Amtholdiel
	local initiatorName,targetName,skillName = string.match(line,"^(.*) verfehlte (.*) mit (.*).");
	
	if (initiatorName ~= nil) then
		initiatorName = string.gsub(initiatorName,"^Der ","");
		initiatorName = string.gsub(initiatorName,"^Die ","");
		targetName = string.gsub(targetName,"^den ","");
		targetName = string.gsub(targetName,"^die ","");
		skillName = string.gsub(skillName, "\"", "");
		avoidType = 2;
		-- Sanity check: must have avoided in some manner
		if (avoidType == 1) then return nil end

		-- Update
		return 1,initiatorName,targetName,skillName,0,avoidType,1,10;
	end
	
	-- 5) Reflect line --
	---Die Amtholdiel reflektierte 27 Punkte Schaden des Typs "Licht" auf Moral von Ghsh-hai der Weien Hand.
	---Der Murk reflektierte 44 Punkte zur Wiederherstellung von Moral von der Rasfiel.

	local initiatorName, amount, reflectType, targetName = string.match(line, "^(.*) reflektierte ([%d,]*) Punkte (.*) von (.*).$");
	
	if(initiatorName ~= nil) then
		local skillName = "Reflektiert";
		initiatorName = string.gsub(initiatorName,"^Die ","");
		initiatorName = string.gsub(initiatorName,"^Der ","");
		targetName = string.gsub(targetName,"^der ","");
		targetName = string.gsub(targetName,"^dem ","");
		targetName = string.gsub(targetName,"^die ","");
		amount = string.gsub(amount,",","")+0;
		local dmgType = string.match(reflectType, "^Schaden des Typs (.*) auf Moral$");
		
		if(dmgType ~= nil) then
			dmgType = 
				dmgType == "Punkte Schaden des Typs \"Allgemein\""  and 1 or
				dmgType == "Punkte Schaden des Typs \"Feuer\"" and 2 or
				dmgType == "Punkte Schaden des Typs \"Blitz\"" and 3 or
				dmgType == "Punkte Schaden des Typs \"Frost\"" and 4 or
				dmgType == "Punkte Schaden des Typs \"S\195\164ure\"" and 5 or
				dmgType == "Punkte Schaden des Typs \"Schatten\"" and 6 or
				dmgType == "Punkte Schaden des Typs \"Licht\"" and 7 or
				dmgType == "Punkte Schaden des Typs \"Beleriand-Art\"" and 8 or
				dmgType == "Punkte Schaden des Typs \"Westernis-Art\"" and 9 or
				dmgType == "Punkte Schaden des Typs \"Uralte Zwergenart\"" and 10 or 11;
			
			--- a dmg reflect
			return 1,initiatorName,targetName,skillName,amount,1,1,dmgType;
		else
			--- a heal reflect
			return 3,initiatorName,targetName,skillName,amount,1;
		end
	end
	
	-- 6) Temporary Morale bubble line (as of 4.1.0)
	local amount = string.match(line,"Ihr habt ([%d,]*) Punkte Moral (temporr) verloren!$");
	if (amount ~= nil) then
		amount = string.gsub(amount,",","")+0;
		return 14,nil,player.name,nil,amount;
	end
	
	----- TODO -----
	
	-- 7) Combat State Break notice (as of 4.1.0)
	
	-- 7a) Root broken
	local targetName = string.match(line,"^.* ha[sv]e? released (.*) from being immobilized!$");
	if (targetName ~= nil) then
		targetName = string.gsub(targetName,"^[Tt]he ","");
		
		-- the only information we can extract directly is the target name
		return 16,nil,targetName,nil;
	end
	
	-- 7b) Daze broken
	local targetName = string.match(line,"^.* ha[sv]e? freed (.*) from a daze!$");
	if (targetName ~= nil) then
		targetName = string.gsub(targetName,"^[Tt]he ","");
		
		-- the only information we can extract directly is the target name
		return 16,nil,targetName,nil;
	end
	
	-- more?
	
	----- ==== -----
	
	-- 6) Interrupt line --
	---Der Buufuu wurde durch die Amtholdiel unterbochen!
	---Die Amtholdiel wurde durch die Phillipa unterbochen!
	
	local targetName,initiatorName = string.match(line,"^(.*) wurde durch (.*) unterbochen!");
	if (targetName ~= nil) then
		initiatorName = string.gsub(initiatorName,"^die ","");
		initiatorName = string.gsub(initiatorName,"^den ","");
		targetName = string.gsub(targetName,"^Der ","");
		targetName = string.gsub(targetName,"^Die ","");
		
		-- Update
		return 7,initiatorName,targetName;
	end
	
	-- 7) Dispell line (corruption removal) --
	---Von ble Inspiration geheilt: Moria-Saboteur
	---Von Blutrnstige Rage geheilt: Durub-Plnderer
	
	local corruption, targetName = string.match(line,"Von (.*) geheilt: (.*)");
	
	if (corruption ~= nil) then
		initiatorName = player.name;
		---targetName = string.gsub(targetName,"^Den ","");
		---targetName = string.gsub(targetName,"^Die ","");
		
		-- NB: Currently ignore corruption name
		
		-- Update
		return 8,initiatorName,targetName;
	end
	
	-- 8) Defeat lines ---
	
	-- 8a) Defeat line 1 (mob or played was killed)
	local initiatorName = string.match(line,"^.* besiegt: (.*)%.$");
	
	if (initiatorName ~= nil) then
		initiatorName = string.gsub(initiatorName,"^den ","");
		initiatorName = string.gsub(initiatorName,"^die ","");
		
		-- Update
		return 9,initiatorName;
	end
	
	----- TODO -----
	
	-- 8b) Defeat line 2 (mob died)
	local initiatorName = string.match(line,"^(.*) died%.$");

	if (initiatorName ~= nil) then
		initiatorName = string.gsub(initiatorName,"^The ","");
		initiatorName = string.gsub(initiatorName,"^the ","");
		
		-- Update
		return 9,initiatorName;
	end
	
	-- 8c) Defeat line 3 (a player was killed or died)
	local initiatorName = string.match(line,"^(.*) has been defeated%.$");

	if (initiatorName ~= nil) then
		initiatorName = string.gsub(initiatorName,"^The ","");
		initiatorName = string.gsub(initiatorName,"^the ","");
		
		-- Update
		return 9,initiatorName;
	end
	
	----- ==== -----
	
	-- 8d) Defeat line 4 (you were killed)
	local match = string.match(line,"^.* hat Euch auer Gefecht gesetzt%.$");

	if (match ~= nil) then
		initiatorName = player.name;
		
		-- Update
		return 9,initiatorName;
	end
	
	-- 8e) Defeat line 5 (you died)
	---Ihr wurdet durch ein Missgeschick auer Gefecht gesetzt.
	local match = string.match(line,"^Ihr wurdet durch ein Missgeschick auer Gefecht gesetzt%.$");

	if (match ~= nil) then
		initiatorName = player.name;
		
		-- Update
		return 9,initiatorName;
	end
	
	-- 9) Revive lines --
	
	----- TODO -----
	
	-- 9a) Revive line 1 (player revived)
	local initiatorName = string.match(line,"^(.*) has been revived%.$");
	
	if (initiatorName ~= nil) then
	  initiatorName = string.gsub(initiatorName,"^The ","");
		initiatorName = string.gsub(initiatorName,"^the ","");
	  
		-- Update
	  return 10,initiatorName;
	end
	
	----- ==== -----
	
	-- 9b) Revive line 2 (player succumbed)
	---Kaisimir ist seinen Wunden erlegen.
	local initiatorName = string.match(line,"^(.*) ist .* Wunden erlegen%.$");
	
	if (initiatorName ~= nil) then
	  initiatorName = string.gsub(initiatorName,"^Der ","");
		initiatorName = string.gsub(initiatorName,"^Die ","");
	  
		-- Update
	  return 10,initiatorName;
	end
	
	----- TODO -----
	
	-- 9c) Revive line 3 (you were revived)
	local match = string.match(line,"^You have been revived%.$");
	
	if (match ~= nil) then
	  initiatorName = player.name;
	  
		-- Update
	  return 10,initiatorName;
	end
	
	----- ==== -----
	
	-- 9d) Revive line 4 (you succumbed)
	---Ihr erliegt Euren Verletzungen.
	local match = string.match(line,"^Ihr erliegt Euren Verletzungen%.$");
	
	if (match ~= nil) then
	  initiatorName = player.name;
	  
		-- Update
	  return 10,initiatorName;
	end
	
	-- if we reach here, we were unable to parse the line
	--  (note there is very little that isn't parsed)
	
end



--[[
	
	Skill Names (for Temporary Morale & Buff/Debuff tracking)
	
	> Temporary Morale Skill Names need specify both how the skill name appears in the combat log, as
	    well as how it appears on the effect tooltip.
	
	> Buff Names must match exactly how the name of a skill appears in the effect tooltip.
	> Benefit/Debuff/Crowd-Control Names must match exactly how the name of a skill appears in the combat log.
	
--]]

-- 0) Temporary Morale Skills {combat log name, effect name}

-- Captain
L["ShieldOfTheDunedainTM"] = {"Schild der D\195\186nedain","Schild der D\195\186nedain"};
-- Champion
L["TrueHeroicsTM"] = {"Wahre Heldentaten","Freude der Schlacht"};
L["SuddenDefenceTM"] = {"Pltzliche Verteidigung","Pltzliche Verteidigung"};
-- Minstrel
L["StoryOfTheHammerhandTM"] = {"Hammerhand-Erzhlung","Lied der Hammerhand"};
L["SongOfTheHammerhandTM"] = {"Dichtung der Hammerhand","Lied der Hammerhand"};
L["GiftOfTheHammerhandTM"] = {"Gabe der Hammerhand","Erzhlung der Hammerhand"};
-- Rune-Keeper
L["WordOfExaltationTM"] = {"Wort des Hochgefhls","Wort des Hochgefhls"};
L["EssayOfExaltationTM"] = {"Abhandlung des Hochgefhls","Wort des Hochgefhls"};

-- 1) Burglar Skills

-- Buffs (effect name)
L["TouchAndGo"] = "Gewandtheit";
L["KnivesOut"] = "Messerkampf";
L["Mischievous"] = "Schelmisch";
L["QuietKnife"] = "Lautloses Messer";
L["Gambler"] = "Spieler";
L["Feint"] = "Tuschen";
L["ImprovedFeint"] = "Verbesserung: Scheinangriff";
-- Debuffs (log name)
L["RevealWeakness"] = "Schwchen aufspren";
L["Addle"] = "Tumult";
L["TrickDisable"] = "Trick: Behindern";
L["TrickCounterDefence"] = "Trick: Abwehr reduzieren";
L["TrickImprovedCounterDefence"] = "Trick: Verbessertes \"Abwehr reduzieren\"";
L["TrickDustInTheEyes"] = "Trick: Staub in die Augen";
L["TrickEnrage"] = "Trick: Erzrnt";
L["ASmallSnag"] = "Ein kleiner Schnitt";
L["QuiteASnag"] = "Ein ziemlicher Haken";
-- Crowd Control (log name)
L["Riddle"] = "Rtsel";
L["ImprovedRiddle"] = "Verbesserung: Rtsel";
L["Confound"] = "Verwirren";
L["StartlingTwist"] = "berraschende Wende";
L["ImprovedStartlingTwist"] = "Verbesserte \"berraschende Wende\"";
L["AdvancedStartlingTwist"] = "Bessere berraschende Wende";
L["ExploitOpening"] = "Exploit Opening"; -- TODO
L["Trip"] = "Trip"; -- TODO
L["Marbles"] = "Marbles"; -- TODO

-- 2) Captain Skills

-- Buffs (effect name)
L["MusterCourage"] = "Mut";
L["InHarmsWay"] = "In den Weg werfen";
L["WarCry"] = "Kriegsschrei";
L["BladeOfElendil"] = "Licht Elendils";
L["Motivated"] = "Motiviert";
L["OnGuard"] = "In Bereitschaft";
L["RelentlessAttack"] = "Gnadenloser Angriff";
L["Focus"] = "Fokus";
L["ShieldBrother"] = "Schildbruder";
L["WatchfulShieldBrother"] = "Wachsamer Schildbruder";
L["SongBrother"] = "Liedbruder";
L["BladeBrother"] = "Klingenbruder";
L["ToArmsShieldBrother"] = "Zu den Waffen (Schildbruder)";
L["ToArmsFellowshipShieldBrother"] = "Zu den Waffen (Gefhrtengruppen-Schildbruder)";
L["ToArmsSongBrother"] = "Zu den Waffen (Liedbruder)";
L["ToArmsFellowshipSongBrother"] = "Zu den Waffen (Gefhrtengruppen-Liedbruder)";
L["ToArmsBladeBrother"] = "Zu den Waffen (Klingenbruder)";
L["ToArmsFellowshipBladeBrother"] = "Zu den Waffen (Gefhrtengruppen-Klingenbruder)";
L["StrengthOfWillShieldBrother"] = "Willenskraft (Schildbruder)";
L["StrengthOfWillFellowshipShieldBrother"] = "Willenskraft (Gefhrtengruppen-Schildbruder)";
L["StrengthOfWillSongBrother"] = "Willenskraft (Liedbruder)";
L["StrengthOfWillFellowshipSongBrother"] = "Willenskraft (Gefhrtengruppen-Liedbruder)";
L["StrengthOfWillBladeBrother"] = "Willenskraft (Klingenbruder)";
L["StrengthOfWillFellowshipBladeBrother"] = "Willenskraft (Gefhrtengruppen-Klingenbruder)";
L["RallyingCry"] = "Racheschrei";
L["InDefenceOfMiddleEarth"] = "Verteidigung von Mittelerde";
L["DefensiveStrike"] = "Defensiver Schlag";
L["ImprovedDefensiveStrike"] = "Verbesserung: Defensiver Schlag";
L["LastStand"] = "Letztes Gefecht";
-- Debuffs (log name)
L["NobleMark"] = "Edles Zeichen";
L["TellingMark"] = "Zeichen setzen";
L["RevealingMark"] = "Verrterisches Zeichen";

-- 3) Champion Skills

-- Buffs (effect name)
L["Fervour"] = "Leidenschaft des Waffenmeisters";
L["Glory"] = "Ruhm";
L["Ardour"] = "Eifer";
L["ControlledBurn"] = "Kontrollierte Wut";
L["Flurry"] = "Wirbel";
L["SuddenDefence"] = "Pltzliche Verteidigung";
L["SeekingBlades"] = "Suchende Klingen";
L["Adamant"] = "Felsenfest";
L["Invincible"] = "Unbesiegbar";
-- Benefits (log name)
L["EbbingIre"] = "Zorn verkleinern";
L["RisingIre"] = "Zorn vergrern";

-- 4) Guardian Skills

-- Buffs (effect name)
L["Protection"] = "Schutz";
L["ProtectionByTheSword"] = "Schutz durch das Schwert";
L["ShieldWall"] = "Schildwall";
L["GuardiansBlockStance"] = "Verteidigung des Wchters";
L["GuardiansParryStance"] = "Parade des Wchters";
L["Overpower"] = "bermannen";
L["GuardiansThreatStance"] = "Bedrohung des Wchters";
L["GuardiansPledge"] = "Gelbnis des Wchters";
L["GuardiansWard"] = "Wchterschild";
L["ImprovedGuardiansWard"] = "Verbesserung: Wchterschild";
L["GuardiansWardTactics"] = "Wchterschild-Taktiken";
L["ImprovedGuardiansWardTactics"] = "Verbesserung: Wchterschild-Taktiken";
L["WarriorsBlock"] = "Blocken des Kriegers";
L["WarriorsParry"] = "Parade des Kriegers";
L["WarriorsPower"] = "Macht des Kriegers";
L["WarriorsThreat"] = "Bedrohung des Kriegers";
-- Debuffs (log name)
L["ImprovedOverwhelm"] = "Verbesserung: bermannen";

-- 5) Hunter Skills

-- Buffs (effect name)
L["StanceStrength"] = "Haltung: Strke";
L["StancePrecision"] = "Haltung: Przision";
L["StanceEndurance"] = "Haltung: Ausdauer";
L["BurnHot"] = "Heisse Flamme";
L["CoolBurn"] = "Selbstbeherrschte Flamme";
L["Fleetness"] = "Schnellfssigkeit";
L["ImprovedFleetness"] = "Verbesserte Schnellfssigkeit";
L["SwiftStroke"] = "Schneller Hieb";
L["NeedfulHaste"] = "Ntige Hast";
L["HuntersArt"] = "Kunst des Jgers";
-- Crowd Control (log name)
L["DazingBlow"] = "Betubender Schlag";
L["ImprovedDazingBlow"] = "Verbesserter betubender Schlag";
L["DistractingShot"] = "Irritierender Schuss";
L["RainOfThorns"] = "Dornenregen";
L["CryOfThePredator"] = "Ruf des Raubtiers";
L["BardsArrow"] = "Bards Pfeil";
L["TrapDamage"] = "Fallenschaden";

-- 6) Lore-Master Skills

-- Buffs (effect name)
L["AirLore"] = "Prickelnde Luft";
L["ContinualAirLore"] = "Prickelnde Luft";
L["SignOfPowerRighteousness"] = "Z.d.M.: Rechtschaffenheit";
L["SignOfPowerVigilance"] = "Z. d. Macht: Wachsamkeit";
L["SignOfTheWildRage"] = "Zeichen der Wildnis: Wut";
L["ImprovedSignOfTheWildRage"] = "Verbessertes Zeichen der Wildnis: Wut";
L["SignOfTheWildProtection"] = "Z. d. Wildnis: Schutz";
-- Debuffs (log name)
L["KnowledgeOfTheLoreMaster"] = "Wissen des Kundigen";
L["GustOfWind"] = "Windsto";
L["FireLore"] = "Feuerkunde";
L["WindLore"] = "Windkunde";
L["FrostLore"] = "Frostwissen";
L["AncientCraft"] = "Uraltes Handwerk";
L["SignOfPowerCommand"] = "Zeichen der Macht: Befehl";
L["ImprovedSignOfPowerCommand"] = "Zeichen der Macht: Verbesserter Befehl";
L["SignOfPowerSeeAllEnds"] = "Zeichen der Macht: Umsichtigkeit";
-- Crowd Control (log name)
L["BlindingFlash"] = "Blendender Blitzstrahl";
L["ImprovedBlindingFlash"] = "Verbesserung: Blendender Blitzstrahl";
L["BaneFlare"] = "Bannglhen";
L["HerbLore"] = "Kruterkunde";
L["CrackedEarth"] = "Rissige Erde";

-- 7) Minstrel Skills

-- Buffs (effect name)
L["AnthemOfWar"] = "Hymne des Krieges";
L["AnthemOfTheFreePeoples"] = "Hymne der freien Vlker";
L["AnthemOfProwess"] = "Hymne der Tchtigkeit";
L["AnthemOfComposure"] = "Hymne der Selbstbeherrschung";
L["TheMelodyOfBattle"] = "Melodie des Kampfes";
L["InspireFellows"] = "Strkung durch \"Gefhrten inspirieren\"";
L["SoliloquyOfSpirit"] = "Selbstgesprch des Geistes";
L["ImprovedChordOfSalvation"] = "Belebender Akkord";
L["TaleOfHeroism"] = "Heldensage";
L["TaleOfBattle"] = "Geschichte des Gefechts";
L["TaleOfWarding"] = "Geschichte der Bewachung";
L["TaleOfWardingAndHope"] = "Geschichte der Bewachung und Hoffnung";
L["TaleOfFrostAndFlame"] = "Geschichte von Frost- und Flamme";
L["TaleOfFrostAndFlamesBattle"] = "Geschichte vom Frost- und Flammengefecht";
L["TaleOfWardingAndHeroism"] = "Verbesserung: Geschichte der Bewachung";
L["SymphonyOfTheHopefulHeart"] = "Symphonie des hoffnungsvollen Herzens";
L["Harmony"] = "Harmonie";
L["WarSpeech"] = "Kriegsrede";
L["AnthemOfCompassion"] = "Hymne des Mitgefhls";
L["AnthemOfTheThirdAge"] = "Hymne des Dritten Zeitalters";
L["AnthemOfTheThirdAgeWarSpeech"] = "Hymne des Dritten Zeitalters (Kriegsrede)";
L["AnthemOfTheThirdAgeHarmony"] = "Hymne des Dritten Zeitalters (Harmonie)";
L["MinorBallad"] = "Bonus: Balladenschaden";
L["MajorBallad"] = "Balladenheilungs-Bonus";
L["PerfectBallad"] = "Bonus: Balladenkraft";
L["StillAsDeath"] = "Todesstarre";
-- Crowd Control (log name)
L["SongOfTheDead"] = "Lied der Toten";
L["InvocationOfElbereth"] = "Schrei der Valar";

-- 8) Rune-Keeper Skills

-- Buffs (effect name)
L["DoNotFallToStorm"] = "Blitz nicht unterliegen";
L["DoNotFallToFlame"] = "Feuer nicht unterliegen";
L["DoNotFallToWinter"] = "Frost nicht unterliegen";
L["DoNotFallThisDay"] = "Tod heute nicht unterliegen";
L["ShallNotFallThisDay"] = "Soll heute nicht Fallen";
L["PreludeToHope"] = "Prludium der Hoffnung";
L["RuneOfRestoration"] = "Rune der Wiederherstellung";
L["WritOfHealthTier1"] = "Sinnbild der Gesundheit - Stufe 1";
L["WritOfHealthTier2"] = "Sinnbild der Gesundheit - Stufe 2";
L["WritOfHealthTier3"] = "Sinnbild der Gesundheit - Stufe 3";
L["OurFatesEntwined"] = "Verbundenes Schicksal";
L["AllFatesEntwined"] = "Alle Schicksale verbunden";
L["GloriousForeshadowing"] = "Glorreiche Ahnungen";
L["WondrousForeshadowing"] = "Wundersame Ahnungen";

-- 9) Warden Skills

-- Buffs (effect name)
L["Conviction"] = "berzeugung";
L["DeterminationStance"] = "Entschlossenheit des Hters";
L["Conservation"] = "Schonung";
L["Recklessness"] = "Unvorsichtigkeit";
L["WayOfTheWarden"] = "Weg des Hters";
L["ShieldBashBlock"] = "Heftiger Schildschag - Blocken";
L["WallOfSteelParry"] = "Stahlwand - Parieren";
L["AdroitManoeuvre"] = "Geschicktes Manver";
L["WardensTriumph"] = "Triumph des Hters";
L["DefensiveStrikeBlock"] = "Defensiver Schlag - Blocken";
L["Persevere"] = "Durchhalten";
L["ShieldDefence"] = "Schild-Verteidigung";
L["ShieldMastery"] = "Schildbeherrschung";
L["DanceOfBattleEvade"] = "Tanz des Kampfes - Ausweichen";
L["ShieldTactics"] = "Schild-Taktiken";
L["TacticallySound"] = "Taktisch einwandfrei";
L["T1HealOverTime"] = "Stufe 1 Heilung ber Zeit";
L["T2HealOverTime"] = "Medium HoT";
L["T3HealOverTime"] = "Stufe 3 Heilung ber Zeit";
L["T4HealOverTime"] = "Stufe 4 Heilung ber Zeit";

-- 10) Racial Skills
L["DutyBound"] = "Duty Bound"; -- TODO

